@@ -9,6 +9,10 @@ from labstep.entities.file.repository import fileRepository
 
 class CommentRepository:
     def getComments(self, entity, count=100, extraParams={}):
+
+        if entity.thread is None:
+            return []
+
         params = {
             "parent_thread_id": entity.thread["id"],
             "search": None,
@@ -17,6 +21,9 @@ class CommentRepository:
         return entityRepository.getEntities(entity.__user__, Comment, count, params)
 
     def addComment(self, entity, body, fileId=None, extraParams={}):
+        if entity.thread is None:
+            raise Exception('You cannot add a comment to this entity')
+
         threadId = entity.thread["id"]
 
         params = {
@@ -39,5 +46,15 @@ class CommentRepository:
         params = {"body": body, **extraParams}
         return entityRepository.editEntity(comment, params)
 
+    def exportComment(self, comment, rootPath):
+        commentDir = entityRepository.exportEntity(comment, rootPath)
+
+        # export comment
+        nestedCommentsDir = commentDir.joinpath('comments')
+        nestedComments = comment.getComments(count=1000)
+
+        for nestedComment in nestedComments:
+            nestedComment.export(nestedCommentsDir)
+
 
 commentRepository = CommentRepository()
