@@ -28,8 +28,9 @@ class Experiment(PrimaryEntity):
 
     def __init__(self, data, user):
         super().__init__(data, user)
-        if hasattr(self, "root_experiment"):
-            self.root_experiment = ExperimentProtocol(self.root_experiment, user)
+        if "root_experiment" in data:
+            self.root_experiment = ExperimentProtocol(
+                data['root_experiment'], user)
 
     def edit(self, name=None, entry=None, started_at=None, extraParams={}):
         """
@@ -47,7 +48,7 @@ class Experiment(PrimaryEntity):
 
         Returns
         -------
-        :class:`~labstep.experiment.Experiment`
+        :class:`~labstep.entities.experiment.model.Experiment`
             An object representing the edited Experiment.
 
         Example
@@ -103,11 +104,11 @@ class Experiment(PrimaryEntity):
         Parameters
         ----------
         protocol (Protocol)
-            The :class:`~labstep.protocol.Protocol` to attach.
+            The :class:`~labstep.entities.protocol.model.Protocol` to attach.
 
         Returns
         -------
-        :class:`~labstep.protocol.Protocol`
+        :class:`~labstep.entities.protocol.model.Protocol`
             An object representing the Protocol attached to the Experiment.
 
         Example
@@ -133,7 +134,7 @@ class Experiment(PrimaryEntity):
 
         Returns
         -------
-        List[:class:`~labstep.experiment.ExperimentProtocol`]
+        List[:class:`~labstep.entities.experimentProtocol.model.ExperimentProtocol`]
             List of the Protocols attached to the Experiment.
 
         Example
@@ -188,7 +189,7 @@ class Experiment(PrimaryEntity):
 
         Returns
         -------
-        :class:`~labstep.metadata.Metadata`
+        :class:`~labstep.entities.metadata.model.Metadata`
             An object representing the new Labstep Data Element.
 
         Example
@@ -216,7 +217,7 @@ class Experiment(PrimaryEntity):
 
         Returns
         -------
-        :class:`~labstep.metadata.Metadata`
+        :class:`~labstep.entities.metadata.model.Metadata`
             An array of objects representing Data Elements
             on a Protocol within an Experiment.
 
@@ -236,7 +237,7 @@ class Experiment(PrimaryEntity):
 
         Returns
         -------
-        List[:class:`~labstep.experiment.ExperimentSignature`]
+        List[:class:`~labstep.entities.experimentSignature.model.ExperimentSignature`]
             List of the signatures added to the Experiment
         """
         exp = self.__user__.getExperiment(self.id)
@@ -255,7 +256,7 @@ class Experiment(PrimaryEntity):
 
         Returns
         -------
-        :class:`~labstep.experiment.ExperimentSignature`
+        :class:`~labstep.entities.experimentSignature.model.ExperimentSignature`
             The signature that has been added
         """
         from labstep.generic.entity.repository import entityRepository
@@ -273,7 +274,7 @@ class Experiment(PrimaryEntity):
 
         Returns
         -------
-        List[:class:`~labstep.experiment.ExperimentMaterial`]
+        List[:class:`~labstep.entities.experimentMaterial.model.ExperimentMaterial`]
             List of the materials in an Experiment.
 
         Example
@@ -307,14 +308,14 @@ class Experiment(PrimaryEntity):
         units (str)
             The units for the amount.
         resource_id (int)
-            The id of the :class:`~labstep.resource.Resource` used.
+            The id of the :class:`~labstep.entities.resource.model.Resource` used.
         resource_item_id (ResourceItem)
             The id of the specific
-            :class:`~labstep.resource.ResourceItem` used.
+            :class:`~labstep.entities.resource.model.ResourceItem` used.
 
         Returns
         -------
-        :class:`~labstep.experiment.ExperimentMaterial`
+        :class:`~labstep.entities.experimentMaterial.model.ExperimentMaterial`
             The newly added material entity.
 
         Example
@@ -395,7 +396,7 @@ class Experiment(PrimaryEntity):
 
         Returns
         -------
-        :class:`~labstep.experiment.ExperimentTable`
+        :class:`~labstep.entities.experimentTable.model.ExperimentTable`
             The newly added table entity.
 
         Example
@@ -425,5 +426,12 @@ class Experiment(PrimaryEntity):
         """
         from labstep.generic.entity.repository import entityRepository
 
-        params = {"experiment_id": self.root_experiment.id, "name": name, "data": data}
+        params = {"experiment_id": self.root_experiment.id,
+                  "name": name, "data": data}
         return entityRepository.newEntity(self.__user__, ExperimentTable, params)
+
+    def export(self, path):
+
+        from labstep.entities.experiment.repository import experimentRepository
+
+        return experimentRepository.exportExperiment(self, path)
