@@ -2,6 +2,9 @@
 # -*- coding: utf-8 -*-
 # Author: Barney Walker <barney@labstep.com>
 
+import os
+import json
+from pathlib import Path
 from labstep.service.helpers import (
     getTime,
     createdAtFrom,
@@ -12,6 +15,7 @@ from labstep.service.helpers import (
 from labstep.entities.experiment.model import Experiment, ExperimentProtocol
 from labstep.service.request import requestService
 from labstep.generic.entity.repository import entityRepository
+from labstep.service.htmlExport import htmlExportService
 
 
 class ExperimentRepository:
@@ -80,5 +84,34 @@ class ExperimentRepository:
 
         return entityRepository.editEntity(experiment, params)
 
+    def exportExperiment(self, experiment, root_path):
+
+        expDir = entityRepository.exportEntity(experiment, root_path)
+
+        # export entry
+        entryDir = expDir.joinpath('entry')
+        experiment.update().root_experiment.update().export(entryDir)
+
+        # export protocols
+        protocolsDir = expDir.joinpath('protocols')
+        protocols = experiment.getProtocols(count=100)
+
+        for protocol in protocols:
+            protocol.export(protocolsDir)
+
+        # export notes
+        notesDir = expDir.joinpath('notes')
+        notes = experiment.getComments(count=1000)
+
+        for note in notes:
+            note.export(notesDir)
+
+        # get html
+        html = htmlExportService.getHTML(experiment)
+        html_with_paths = htmlExportService.insertFilepaths(expDir, html)
+
+        with open(expDir.joinpath('entity.html'), 'w') as out:
+            out.write(html_with_paths)
+
 
 experimentRepository = ExperimentRepository()
