@@ -10,6 +10,7 @@ from labstep.entities.experimentMaterial.model import ExperimentMaterial
 from labstep.entities.experimentStep.model import ExperimentStep
 from labstep.entities.experimentTable.model import ExperimentTable
 from labstep.entities.experimentTimer.model import ExperimentTimer
+from labstep.entities.experimentMaterial.repository import experimentMaterialRepository
 
 
 class ExperimentProtocol(Entity):
@@ -38,7 +39,7 @@ class ExperimentProtocol(Entity):
 
         Returns
         -------
-        :class:`~labstep.experiment.ExperimentProtocol`
+        :class:`~labstep.entities.experimentProtocol.model.ExperimentProtocol`
             An object representing the edited ExperimentProtocol.
 
         Example
@@ -76,13 +77,13 @@ class ExperimentProtocol(Entity):
         self.update()
         return getattr(self, "state", None)
 
-    def getMaterials(self):
+    def getMaterials(self, count=100, extraParams={}):
         """
         Returns a list of the materials in a Protocol within an Experiment.
 
         Returns
         -------
-        List[:class:`~labstep.experiment.ExperimentMaterial`]
+        List[:class:`~labstep.entities.experimentMaterial.model.ExperimentMaterial`]
             List of the materials in an Experiment's Protocol.
 
         Example
@@ -94,9 +95,8 @@ class ExperimentProtocol(Entity):
             exp_protocol_materials = exp_protocol.getMaterials()
             exp_protocol_materials[0].attributes()
         """
-        self.update()
-        materials = self.experiment_values
-        return listToClass(materials, ExperimentMaterial, self.__user__)
+        return experimentMaterialRepository.getExperimentMaterials(self.__user__,
+                                                                   experiment_id=self.id, count=count, extraParams=extraParams)
 
     def addMaterial(
         self,
@@ -119,14 +119,14 @@ class ExperimentProtocol(Entity):
         units (str)
             The units for the amount.
         resource_id (int)
-            The id of the :class:`~labstep.resource.Resource` used.
+            The id of the :class:`~labstep.entities.resource.model.Resource` used.
         resource_item_id (ResourceItem)
             The id of the specific
-            :class:`~labstep.resource.ResourceItem` used.
+            :class:`~labstep.entities.resource.model.ResourceItem` used.
 
         Returns
         -------
-        :class:`~labstep.experiment.ExperimentMaterial`
+        :class:`~labstep.entities.experimentMaterial.model.ExperimentMaterial`
             The newly added material entity.
 
         Example
@@ -138,22 +138,13 @@ class ExperimentProtocol(Entity):
             experiment.addMaterial(name='Sample A', amount='2', units='ml',
                                  resource_id=resource.id)
         """
-        from labstep.generic.entity.repository import entityRepository
-
-        params = {
-            "experiment_id": self.id,
-            "name": name,
-            "resource_id": resource_id,
-            "resource_item_id": resource_item_id,
-            "value": amount,
-            "units": units,
-            **extraParams,
-        }
-
-        if params["value"] is not None:
-            params["value"] = str(params["value"])
-
-        return entityRepository.newEntity(self.__user__, ExperimentMaterial, params)
+        return experimentMaterialRepository.newExperimentMaterial(self.__user__,
+                                                                  name=name,
+                                                                  amount=amount,
+                                                                  units=units,
+                                                                  resource_id=resource_id,
+                                                                  resource_item_id=resource_item_id,
+                                                                  extraParams=extraParams)
 
     def addSteps(self, N):
         """
@@ -190,7 +181,7 @@ class ExperimentProtocol(Entity):
 
         Returns
         -------
-        :class:`~labstep.experiment.ExperimentTable`
+        :class:`~labstep.entities.experimentTable.model.ExperimentTable`
             The newly added table entity.
 
         Example
@@ -230,7 +221,7 @@ class ExperimentProtocol(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.experiment.ExperimentStep`]
+        List[:class:`~labstep.entities.experimentStep.model.ExperimentStep`]
             List of the steps in an Experiment's Protocol.
 
         Example
@@ -252,7 +243,7 @@ class ExperimentProtocol(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.experiment.ExperimentTable`]
+        List[:class:`~labstep.entities.experimentTable.model.ExperimentTable`]
             List of the tables in an Experiment's Protocol.
 
         Example
@@ -274,7 +265,7 @@ class ExperimentProtocol(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.experiment.ExperimentTimer`]
+        List[:class:`~labstep.entities.experimentTimer.model.ExperimentTimer`]
             List of the timers in an Experiment's Protocol.
 
         Example
@@ -296,7 +287,7 @@ class ExperimentProtocol(Entity):
 
         Returns
         -------
-        :class:`~labstep.metadata.Metadata`
+        :class:`~labstep.entities.metadata.model.Metadata`
             An array of objects representing the Labstep
             Data Elements on a Protocol within an Experiment.
 
@@ -347,7 +338,7 @@ class ExperimentProtocol(Entity):
 
         Returns
         -------
-        :class:`~labstep.metadata.Metadata`
+        :class:`~labstep.entities.metadata.model.Metadata`
             An object representing the new Labstep Data Element.
 
         Example
@@ -373,3 +364,7 @@ class ExperimentProtocol(Entity):
             filepath=filepath,
             extraParams=extraParams,
         )
+
+    def export(self, rootPath):
+        from labstep.entities.experimentProtocol.repository import experimentProtocolRepository
+        return experimentProtocolRepository.exportExperimentProtocol(self, rootPath)
