@@ -9,6 +9,7 @@ from labstep.entities.protocolStep.model import ProtocolStep
 from labstep.entities.protocolTable.model import ProtocolTable
 from labstep.entities.protocolTimer.model import ProtocolTimer
 from labstep.entities.protocolVersion.model import ProtocolVersion
+from labstep.entities.protocolMaterial.repository import protocolMaterialRepository
 from labstep.service.helpers import (
     listToClass,
     getTime,
@@ -45,7 +46,7 @@ class Protocol(PrimaryEntity):
 
         Returns
         -------
-        :class:`~labstep.protocol.Protocol`
+        :class:`~labstep.entities.protocol.model.Protocol`
             An object representing the edited Protocol.
 
         Example
@@ -158,7 +159,7 @@ class Protocol(PrimaryEntity):
 
         Returns
         -------
-        List[:class:`~labstep.protocol.ProtocolStep`]
+        List[:class:`~labstep.entities.protocolStep.model.ProtocolStep`]
             List of the steps in Protocol.
 
         Example
@@ -181,7 +182,7 @@ class Protocol(PrimaryEntity):
 
         Returns
         -------
-        :class:`~labstep.metadata.Metadata`
+        :class:`~labstep.entities.metadata.model.Metadata`
             An array of objects representing the Labstep Data Elements
             on a Protocol.
 
@@ -232,7 +233,7 @@ class Protocol(PrimaryEntity):
 
         Returns
         -------
-        :class:`~labstep.metadata.Metadata`
+        :class:`~labstep.entities.metadata.model.Metadata`
             An object representing the new Labstep Data Element.
 
         Example
@@ -273,12 +274,12 @@ class Protocol(PrimaryEntity):
         units (str)
             The units for the amount.
         resource_id (int)
-            The id of the :class:`~labstep.resource.Resource` recommended for
+            The id of the :class:`~labstep.entities.resource.model.Resource` recommended for
             use with the protocol.
 
         Returns
         -------
-        :class:`~labstep.protocol.ProtocolMaterial`
+        :class:`~labstep.entities.protocolMaterial.model.ProtocolMaterial`
             The newly added material entity.
 
         Example
@@ -306,13 +307,13 @@ class Protocol(PrimaryEntity):
 
         return entityRepository.newEntity(self.__user__, ProtocolMaterial, params)
 
-    def getMaterials(self):
+    def getMaterials(self, count=100, extraParams={}):
         """
         Returns a list of the materials in a Protocol.
 
         Returns
         -------
-        List[:class:`~labstep.protocol.ProtocolMaterial`]
+        List[:class:`~labstep.entities.protocolMaterial.model.ProtocolMaterial`]
             List of the materials in a Protocol.
 
         Example
@@ -323,11 +324,10 @@ class Protocol(PrimaryEntity):
             protocol_materials = protocol.getMaterials()
             protocol_materials[0].attributes()
         """
-        self.update()
-        if "protocol_values" not in self.last_version:
-            return []
-        materials = self.last_version["protocol_values"]
-        return listToClass(materials, ProtocolMaterial, self.__user__)
+        return protocolMaterialRepository.getProtocolMaterials(self.__user__,
+                                                               protocol_id=self.last_version['id'],
+                                                               count=count,
+                                                               extraParams=extraParams)
 
     def addTimer(self, name=None, hours=None, minutes=None, seconds=None):
         """
@@ -346,7 +346,7 @@ class Protocol(PrimaryEntity):
 
         Returns
         -------
-        :class:`~labstep.protocol.ProtocolTimer`
+        :class:`~labstep.entities.protocolTimer.model.ProtocolTimer`
             The newly added timer entity.
 
         Example
@@ -373,7 +373,7 @@ class Protocol(PrimaryEntity):
 
         Returns
         -------
-        List[:class:`~labstep.protocol.ProtocolTimer`]
+        List[:class:`~labstep.entities.protocolTimer.model.ProtocolTimer`]
             List of the timers in a Protocol.
 
         Example
@@ -404,7 +404,7 @@ class Protocol(PrimaryEntity):
 
         Returns
         -------
-        :class:`~labstep.protocol.ProtocolTable`
+        :class:`~labstep.entities.protocolTable.model.ProtocolTable`
             The newly added table entity.
 
         Example
@@ -434,7 +434,8 @@ class Protocol(PrimaryEntity):
         """
         from labstep.generic.entity.repository import entityRepository
 
-        params = {"protocol_id": self.last_version["id"], "name": name, "data": data}
+        params = {
+            "protocol_id": self.last_version["id"], "name": name, "data": data}
         return entityRepository.newEntity(self.__user__, ProtocolTable, params)
 
     def getTables(self):
@@ -443,7 +444,7 @@ class Protocol(PrimaryEntity):
 
         Returns
         -------
-        List[:class:`~labstep.protocol.ProtocolTable`]
+        List[:class:`~labstep.entities.protocolTable.model.ProtocolTable`]
             List of the tables in a Protocol.
 
         Example
