@@ -27,12 +27,12 @@ class ProtocolMaterial(Entity):
         units (str)
             The units of the amount.
         resource_id (Resource)
-            The id of the :class:`~labstep.resource.Resource` of
+            The id of the :class:`~labstep.entities.resource.model.Resource` of
             the Protocol Material.
 
         Returns
         -------
-        :class:`~labstep.protocol.ProtocolMaterial`
+        :class:`~labstep.entities.protocolMaterial.model.ProtocolMaterial`
             An object representing the edited Protocol Material.
 
         Example
@@ -43,13 +43,6 @@ class ProtocolMaterial(Entity):
             protocol_materials = exp_protocol.getMaterials()
             protocol_materials[0].edit(value=1.7, units='ml')
         """
-        from labstep.generic.entity.repository import entityRepository
+        from labstep.entities.protocolMaterial.repository import protocolMaterialRepository
 
-        params = {
-            "name": name,
-            "resource_id": resource_id,
-            "value": amount,
-            "units": units,
-            **extraParams,
-        }
-        return entityRepository.editEntity(self, params)
+        return protocolMaterialRepository.editEntity(self, amount=amount, units=units, resource_id=resource_id)
