@@ -47,7 +47,7 @@ class User(Entity):
 
         Returns
         -------
-        :class:`~labstep.workspace.Workspace`
+        :class:`~labstep.entities.workspace.model.Workspace`
             An object representing a Workspace on Labstep.
 
         Example
@@ -74,7 +74,7 @@ class User(Entity):
 
         Returns
         -------
-        :class:`~labstep.experiment.Experiment`
+        :class:`~labstep.entities.experiment.model.Experiment`
             An object representing an Experiment on Labstep.
 
         Example
@@ -98,7 +98,7 @@ class User(Entity):
 
         Returns
         -------
-        :class:`~labstep.protocol.Protocol`
+        :class:`~labstep.entities.protocol.model.Protocol`
             An object representing a Protocol on Labstep.
 
         Example
@@ -122,7 +122,7 @@ class User(Entity):
 
         Returns
         -------
-        :class:`~labstep.resource.Resource`
+        :class:`~labstep.entities.resource.model.Resource`
             An object representing a Resource on Labstep.
 
         Example
@@ -135,6 +135,30 @@ class User(Entity):
 
         return resourceRepository.getResource(self, resource_id)
 
+    def getResourceItem(self, resource_item_id):
+        """
+        Retrieve a specific Labstep Resource Item.
+
+        Parameters
+        ----------
+        resource_item_id (int)
+            The id of the Resource Item to retrieve.
+
+        Returns
+        -------
+        :class:`~labstep.entities.resourceItem.model.ResourceItem`
+            An object representing a Resource Item on Labstep.
+
+        Example
+        -------
+        ::
+
+            entity = user.getResourceItem(17000)
+        """
+        from labstep.entities.resourceItem.repository import resourceItemRepository
+
+        return resourceItemRepository.getResourceItem(self, resource_item_id)
+
     def getResourceCategory(self, resource_category_id):
         """
         Retrieve a specific Labstep ResourceCategory.
@@ -146,7 +170,7 @@ class User(Entity):
 
         Returns
         -------
-        :class:`~labstep.resourceCategory.ResourceCategory`
+        :class:`~labstep.entities.resourceCategory.model.ResourceCategory`
             An object representing a ResourceCategory on Labstep.
 
         Example
@@ -172,7 +196,7 @@ class User(Entity):
 
         Returns
         -------
-        :class:`~labstep.resourceLocation.ResourceLocation`
+        :class:`~labstep.entities.resourceLocation.model.ResourceLocation`
             An object representing a ResourceLocation on Labstep.
 
         Example
@@ -198,7 +222,7 @@ class User(Entity):
 
         Returns
         -------
-        :class:`~labstep.orderRequest.OrderRequest`
+        :class:`~labstep.entities.orderRequest.model.OrderRequest`
             An object representing a OrderRequest on Labstep.
 
         Example
@@ -222,7 +246,7 @@ class User(Entity):
 
         Returns
         -------
-        :class:`~labstep.workspace.Workspace`
+        :class:`~labstep.entities.workspace.model.Workspace`
             An object representing a Workspace on Labstep.
 
         Example
@@ -246,7 +270,7 @@ class User(Entity):
 
         Returns
         -------
-        :class:`~labstep.file.File`
+        :class:`~labstep.entities.file.model.File`
             An object representing a File on Labstep.
 
         Example
@@ -270,7 +294,7 @@ class User(Entity):
 
         Returns
         -------
-        :class:`~labstep.device.Device`
+        :class:`~labstep.entities.device.model.Device`
             An object representing a Device on Labstep.
 
         Example
@@ -318,7 +342,7 @@ class User(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.experiment.Experiment`]
+        List[:class:`~labstep.entities.experiment.model.Experiment`]
             A list of Labstep Experiments.
 
         Example
@@ -377,7 +401,7 @@ class User(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.protocol.Protocol`]
+        List[:class:`~labstep.entities.protocol.model.Protocol`]
             A list of Labstep Protocols.
 
         Example
@@ -419,7 +443,7 @@ class User(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.resource.Resource`]
+        List[:class:`~labstep.entities.resource.model.Resource`]
             A list of Labstep Resources.
 
         Example
@@ -458,7 +482,7 @@ class User(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.resourceCategory.ResourceCategory`]
+        List[:class:`~labstep.entities.resourceCategory.model.ResourceCategory`]
             A list of Labstep ResourceCategorys.
 
         Example
@@ -492,7 +516,7 @@ class User(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.resourceLocation.ResourceLocation`]
+        List[:class:`~labstep.entities.resourceLocation.model.ResourceLocation`]
             A list of ResourceLocation objects.
 
         Example
@@ -529,7 +553,7 @@ class User(Entity):
         Returns
         -------
 
-        List[:class:`~labstep.orderRequest.OrderRequest`]
+        List[:class:`~labstep.entities.orderRequest.model.OrderRequest`]
             A list of Labstep OrderRequests.
 
         Example
@@ -568,7 +592,7 @@ class User(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.tag.Tag`]
+        List[:class:`~labstep.entities.tag.model.Tag`]
             A list of Labstep Tags.
 
         Example
@@ -602,7 +626,7 @@ class User(Entity):
         Returns
         -------
 
-        List[:class:`~labstep.workspace.Workspace`]
+        List[:class:`~labstep.entities.workspace.model.Workspace`]
             A list of Labstep Workspaces.
 
         Example
@@ -637,7 +661,7 @@ class User(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.file.File`]
+        List[:class:`~labstep.entities.file.model.File`]
             A list of Labstep Files.
 
         Example
@@ -671,7 +695,7 @@ class User(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.device.Device`]
+        List[:class:`~labstep.entities.device.model.Device`]
             A list of Labstep Devices.
 
         Example
@@ -701,7 +725,7 @@ class User(Entity):
 
         Returns
         -------
-        :class:`~labstep.experiment.Experiment`
+        :class:`~labstep.entities.experiment.model.Experiment`
             An object representing an Experiment on Labstep.
 
         Example
@@ -727,7 +751,7 @@ class User(Entity):
 
         Returns
         -------
-        :class:`~labstep.protocol.Protocol`
+        :class:`~labstep.entities.protocol.model.Protocol`
             An object representing a Protocol on Labstep.
 
         Example
@@ -751,7 +775,7 @@ class User(Entity):
 
         Returns
         -------
-        :class:`~labstep.resource.Resource`
+        :class:`~labstep.entities.resource.model.Resource`
             An object representing a Resource on Labstep.
 
         Example
@@ -775,7 +799,7 @@ class User(Entity):
 
         Returns
         -------
-        :class:`~labstep.resourceCategory.ResourceCategory`
+        :class:`~labstep.entities.resourceCategory.model.ResourceCategory`
             An object representing the new Labstep ResourceCategory.
 
         Example
@@ -808,7 +832,7 @@ class User(Entity):
 
         Returns
         -------
-        :class:`~labstep.resourceLocation.ResourceLocation`
+        :class:`~labstep.entities.resourceLocation.model.ResourceLocation`
             An object representing the new Labstep ResourceLocation.
 
         Example
@@ -830,14 +854,14 @@ class User(Entity):
         Parameters
         ----------
         resource_id (int)
-            The id of the :class:`~labstep.resource.Resource`
+            The id of the :class:`~labstep.entities.resource.model.Resource`
             to request more items of.
         quantity (int)
             The quantity of items requested.
 
         Returns
         -------
-        :class:`~labstep.orderRequest.OrderRequest`
+        :class:`~labstep.entities.orderRequest.model.OrderRequest`
             An object representing the an OrderRequest on Labstep.
 
         Example
@@ -868,7 +892,7 @@ class User(Entity):
 
         Returns
         -------
-        :class:`~labstep.tag.Tag`
+        :class:`~labstep.entities.tag.model.Tag`
             An object representing a Tag on Labstep.
 
         Example
@@ -892,7 +916,7 @@ class User(Entity):
 
         Returns
         -------
-        :class:`~labstep.workspace.Workspace`
+        :class:`~labstep.entities.workspace.model.Workspace`
             An object representing a Workspace on Labstep.
 
         Example
@@ -948,7 +972,7 @@ class User(Entity):
 
         Returns
         -------
-        :class:`~labstep.device.Device`
+        :class:`~labstep.entities.device.model.Device`
             An object representing a Device on Labstep.
 
         Example
