@@ -36,7 +36,7 @@ class Workspace(Entity):
 
         Returns
         -------
-        :class:`~labstep.workspace.Workspace`
+        :class:`~labstep.entities.workspace.model.Workspace`
             An object representing the edited Workspace.
 
         Example
@@ -99,7 +99,7 @@ class Workspace(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.experiment.Experiment`]
+        List[:class:`~labstep.entities.experiment.model.Experiment`]
             A list of Labstep Experiments.
 
         Example
@@ -159,7 +159,7 @@ class Workspace(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.protocol.Protocol`]
+        List[:class:`~labstep.entities.protocol.model.Protocol`]
             A list of Labstep Protocols.
 
         Example
@@ -202,7 +202,7 @@ class Workspace(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.resource.Resource`]
+        List[:class:`~labstep.entities.resource.model.Resource`]
             A list of Labstep Resources.
 
         Example
@@ -238,7 +238,7 @@ class Workspace(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.resourceCategory.ResourceCategory`]
+        List[:class:`~labstep.entities.resourceCategory.model.ResourceCategory`]
             A list of Labstep ResourceCategorys.
 
         Example
@@ -270,7 +270,7 @@ class Workspace(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.resourceLocation.ResourceLocation`]
+        List[:class:`~labstep.entities.resourceLocation.model.ResourceLocation`]
             A list of ResourceLocation objects.
 
         Example
@@ -305,7 +305,7 @@ class Workspace(Entity):
         Returns
         -------
 
-        List[:class:`~labstep.orderRequest.OrderRequest`]
+        List[:class:`~labstep.entities.orderRequest.model.OrderRequest`]
             A list of Labstep OrderRequests.
 
         Example
@@ -345,7 +345,7 @@ class Workspace(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.tag.Tag`]
+        List[:class:`~labstep.entities.tag.model.Tag`]
             A list of Labstep Tags.
 
         Example
@@ -376,7 +376,7 @@ class Workspace(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.workspace.Member`]
+        List[:class:`~labstep.entities.member.model.Member`]
             A list of the members of the workspace and their permissions.
 
         Example
@@ -387,7 +387,8 @@ class Workspace(Entity):
         """
         from labstep.generic.entity.repository import entityRepository
 
-        params = {"group_id": self.id, "search_query_user": search_query, **extraParams}
+        params = {"group_id": self.id,
+                  "search_query_user": search_query, **extraParams}
 
         return entityRepository.getEntities(self.__user__, Member, count, params)
 
@@ -409,7 +410,7 @@ class Workspace(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.file.File`]
+        List[:class:`~labstep.entities.file.model.File`]
             A list of Labstep Files.
 
         Example
@@ -440,7 +441,7 @@ class Workspace(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.device.Device`]
+        List[:class:`~labstep.entities.device.model.Device`]
             A list of Labstep Devices.
 
         Example
@@ -487,19 +488,13 @@ class Workspace(Entity):
 
         Returns
         -------
-        :class:`~labstep.sharelink.Sharelink`
+        :class:`~labstep.entities.sharelink.model.Sharelink`
             The sharelink for the workspace
 
         """
 
-        if self.share_link is None:
-            from labstep.entities.sharelink.repository import shareLinkRepository
-
-            return shareLinkRepository.newSharelink(
-                self.__user__, fields={"group_id": self.id}
-            )
-
-        return Sharelink(self.share_link, self.__user__)
+        from labstep.entities.sharelink.repository import shareLinkRepository
+        return shareLinkRepository.getSharelink(self)
 
     def getCollections(
         self, count=1000, search_query=None, type="experiment", extraParams={}
@@ -520,7 +515,7 @@ class Workspace(Entity):
 
         Returns
         -------
-        List[:class:`~labstep.collection.Collection`]
+        List[:class:`~labstep.entities.collection.model.Collection`]
             A list of Labstep Collections.
 
         Example
@@ -559,7 +554,8 @@ class Workspace(Entity):
         from labstep.entities.collection.repository import collectionRepository
 
         return collectionRepository.newCollection(
-            self.__user__, name=name, type=type, extraParams={"group_id": self.id}
+            self.__user__, name=name, type=type, extraParams={
+                "group_id": self.id}
         )
 
     def setHome(self):
@@ -591,7 +587,7 @@ class Workspace(Entity):
 
         Returns
         -------
-        :class:`~labstep.autoshare.Autoshare`
+        :class:`~labstep.entities.autoshare.model.Autoshare`
             An object representing the Autosharing policy.
 
         Example
