@@ -3,19 +3,22 @@
 # Author: Barney Walker <barney@labstep.com>
 
 import inspect
+import json
 import pprint
 from labstep.service.helpers import update
 
 
 class Entity:
-    
+
     def __init__(self, data, user):
         self.__user__ = user
+        self.__data__ = data
         self.id = None
         update(self, data)
 
     def __repr__(self):
-        all_attributes = inspect.getmembers(self, lambda a: not (inspect.isroutine(a)))
+        all_attributes = inspect.getmembers(
+            self, lambda a: not (inspect.isroutine(a)))
         entity_attributes = {
             k: v for k, v in all_attributes if not (k.startswith("__"))
         }
@@ -28,6 +31,11 @@ class Entity:
         """
         from labstep.generic.entity.repository import entityRepository
 
-        data = entityRepository.getEntity(self.__user__, type(self), self.id).__data__
+        data = entityRepository.getEntity(
+            self.__user__, type(self), self.id).__data__
         self.__init__(data, self.__user__)
         return self
+
+    def export(self, rootPath):
+        from labstep.generic.entity.repository import entityRepository
+        return entityRepository.exportEntity(self, rootPath)
